translate.storage.lisa

Package translate :: Package storage :: Module lisa |
[hide private]
[frames] | no frames]

# Module lisa

source code

Parent class for LISA standards (TMX, TBX, XLIFF)

Classes | [hide private]
| LISAunit A single unit in the file.
| LISAfile A class representing a file store for one of the LISA file formats.

Functions | [hide private]
_findAllMatches(text, re_obj) generate match objects for all `re_obj` matches in `text`. | source code
_getPhMatches(text) return list of regexp matchobjects for with all place holders in the `text` | source code

Variables | [hide private]
| placeholders = ``[``'``(%[diouxXeEfFgGcrs])``'``,` `'``(\\\\+.?)``'``,` `'``(%[0-9]$``...``
| re_placeholders = ``[`re.compile(r'`(`%`[`diouxXeEfFgGcrs`]``)`')`,` re.com`...``
| ph = ``'``(<.+?>)``'``

Imports: re, base, data, etree, getText, getXMLlang, setXMLlang, getXMLspace, setXMLspace, namespaced

Variables Details | [hide private]

  ### placeholders Value:
      ['(%[diouxXeEfFgGcrs])',
       '(\\\\+.?)',
       '(%[0-9]$lx)',
       '(%[0-9]\\$[a-z])',
       '(<.+?>)']

  ### re_placeholders Value:
      [re.compile(r'(%[diouxXeEfFgGcrs])'),
       re.compile(r'(\\+.?)'),
       re.compile(r'(%[0-9]$lx)'),
       re.compile(r'(%[0-9]\$[a-z])'),
       re.compile(r'(<.+?>)')]